notetools.Note
==============

.. abjad-lineage:: abjad.tools.notetools.Note.Note.Note

.. autoclass:: abjad.tools.notetools.Note.Note.Note
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.descendants
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.fingered_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.leaf_index
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.lineage
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.override
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.parent
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.parentage
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.prolation
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.set
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.spanners
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.start_offset
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.storage_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.timespan
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.note_head
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.written_duration
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.written_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.Note.Note.Note.written_pitch_indication_is_nonsemantic
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.notetools.Note.Note.Note.__and__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__eq__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__ge__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__gt__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__le__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__lt__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__mul__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__ne__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__or__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__repr__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__rmul__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__str__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__sub__
   :noindex:

.. automethod:: abjad.tools.notetools.Note.Note.Note.__xor__
   :noindex:
